# /*****************************************************************************
# * Copyright (c) [2024] ams-OSRAM AG                                          *
# * All rights are reserved.                                                   *
# *                                                                            *
# * FOR FULL LICENSE TEXT SEE LICENSE.TXT                                      *
# ******************************************************************************/
 

"""Create systemd service for TMF8806 ZeroMQ server."""

from pathlib import Path
from zipfile import ZipFile


def create_systemd_service(service_name, python_script_path, log_file_path):
    """Create and start a systemd service for a Python script.

    Args:
        service_name (str): The name of the systemd service.
        python_script_path (str): The path to the Python script to run as a service.
        log_file_path (str): The path to the file where the output of the service will be logged.

    Returns:
        None

    Side effects:
        Creates a systemd service file at /etc/systemd/system/{service_name}.service
        Enables and starts the systemd service using systemctl
        Prints a message indicating the status of the service creation and start
    """
    service_file_path = f"/etc/systemd/system/{service_name}.service"
    with open(service_file_path, "w", encoding="utf-8") as f:
        f.write("[Unit]\n"
                f"Description={service_name}\n"
                "After=multi-user.target\n"
                "\n"
                "[Service]\n"
                "Type=simple\n"
                "Restart=always\n"
                f"ExecStart=/usr/bin/python3 {python_script_path}\n"
                f"StandardOutput=truncate:{log_file_path}\n"
                f"StandardError=truncate:{log_file_path}\n"
                "\n"
                "[Install]\n"
                "WantedBy=multi-user.target\n"
                )

if __name__ == "__main__":
    import argparse

    parser = argparse.ArgumentParser(description="Install th TMF8806 ZeroMQ server as systemd service.")
    parser.add_argument("pkg_path", help="Path to the TMF8806 server zip file.")
    parser.add_argument("--dest", help="Install destination path", default="/home/ams/zmq_server")
    parser.add_argument("--name", help="Name of the service.", default="tmf8806_zmq_server")
    parser.add_argument("--log", help="Path of the service log file.", default="/var/log/tmf8806_zmq_server.log")
    args = parser.parse_args()

    with ZipFile(args.pkg_path) as f:
        f.extractall(args.dest)

    create_systemd_service(args.name, Path(args.dest, "tmf8806_zmq_server.py"), args.log)
